@@ -43,7 +43,6 @@ from schooltool.app.overlay import ICalendarOverlayInfo
 from schooltool.app.interfaces import IPluginInit, IPluginStartUp
 from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.app.interfaces import IApplicationPreferences
-from schooltool.app.interfaces import IShowTimetables
 from schooltool.app import relationships
 from schooltool.app.interfaces import IAsset
 from schooltool.relationship.relationship import RelationshipProperty
@@ -51,9 +50,6 @@ from schooltool.common import getRequestFromInteraction
 from schooltool.common import SchoolToolMessage as _
 
 
-SHOW_TIMETABLES_KEY = 'schooltool.timetable.showTimetables'
-
-
 class SchoolToolApplication(Persistent, sample.SampleContainer,
                             SiteManagerContainer):
     """The main application object.
@@ -235,58 +231,6 @@ def getApplicationPreferences(app):
         return annotations[key]
 
 
-class ShowTimetables(object):
-    """Adapter from ICalendarOverlayInfo to IShowTimetables.
-
-        >>> from zope.app.testing import setup
-        >>> setup.setUpAnnotations()
-
-        >>> from zope.interface import classImplements
-        >>> from schooltool.app.overlay import CalendarOverlayInfo
-        >>> from zope.annotation.interfaces import IAttributeAnnotatable
-        >>> classImplements(CalendarOverlayInfo, IAttributeAnnotatable)
-
-        >>> calendar = object()
-        >>> info = CalendarOverlayInfo(calendar, True, 'red', 'yellow')
-        >>> info.__parent__ = calendar
-        >>> stt = ShowTimetables(info)
-
-        >>> from zope.interface.verify import verifyObject
-        >>> verifyObject(IShowTimetables, stt)
-        True
-
-        >>> stt.showTimetables
-        True
-
-    The `showTimetables` attribute is changeable:
-
-        >>> stt.showTimetables = False
-        >>> stt.showTimetables
-        False
-
-    We need a __parent__ attribute for local security grants:
-
-        >>> stt.__parent__ is calendar
-        True
-
-    """
-
-    adapts(ICalendarOverlayInfo)
-    implements(IShowTimetables)
-
-    def __init__(self, context):
-        self.annotations = IAnnotations(context)
-        self.__parent__ = context.__parent__ # for local security grants
-
-    def getShowTimetables(self):
-        return self.annotations.get(SHOW_TIMETABLES_KEY, True)
-
-    def setShowTimetables(self, value):
-        self.annotations[SHOW_TIMETABLES_KEY] = value
-
-    showTimetables = property(getShowTimetables, setShowTimetables)
-
-
 class SchoolToolInitializationUtility(object):
 
     def initializeApplication(self, app):
