@@ -360,7 +360,7 @@ class FlourishContactEditView(flourish.page.NoSidebarPage,
                 return absoluteURL(persons[person_id], self.request)
         return absoluteURL(self.context, self.request)
 
-    @button.buttonAndHandler(_("Cancel"))
+    @button.handler(ContactEditView.buttons['cancel'])
     def handle_cancel_action(self, action):
         self.request.response.redirect(self.nextURL())
 
@@ -495,7 +495,7 @@ def format_street_address(item, formatter):
     return ", ".join(address_parts)
 
 
-def contact_table_collumns():
+def contact_table_columns():
         first_name = IndexedLocaleAwareGetterColumn(
             index='first_name',
             name='first_name',
@@ -515,7 +515,7 @@ def contact_table_collumns():
 
 class ContactTableFormatter(IndexedTableFormatter):
 
-    columns = lambda self: contact_table_collumns()
+    columns = lambda self: contact_table_columns()
 
     def sortOn(self):
         return (("first_name", False),)
